@@ -19,8 +19,11 @@ import time
 import uuid
 import json
 import httpx
-import nest_asyncio
-nest_asyncio.apply()
+try:
+    import nest_asyncio
+    nest_asyncio.apply()
+except:
+    pass
 
 class Client:
     @staticmethod
