@@ -6,7 +6,7 @@ import asyncio
 import orjson
 import time
 
-from utils.singleton_wrapper import Singleton
+from hamunafs.utils.singleton_wrapper import Singleton
 
 
 class MQManager(Singleton):
